@@ -7,13 +7,14 @@ import sys
 import re
 import argparse
 
+import iocapture
 import mock
 import pytest
 
 import argh
 from argh.exceptions import AssemblingError
 
-from .base import DebugArghParser, run, CmdResult as R
+from .base import DebugArghParser, get_usage_string, run, CmdResult as R
 
 
 @pytest.mark.xfail(reason='TODO')
@@ -760,6 +761,22 @@ def test_help_formatting_is_preserved():
     assert func.__doc__ in p.format_help()
 
 
+def test_prog():
+    "Program name propagates from sys.argv[0]"
+
+    def cmd(foo=1):
+        return foo
+
+    p = DebugArghParser()
+    p.add_commands([cmd])
+
+    usage = get_usage_string()
+
+    with iocapture.capture() as captured:
+        assert run(p, '-h', exit=True) == None
+        assert captured.stdout.startswith(usage)
+
+
 def test_unknown_args():
 
     def cmd(foo=1):
@@ -768,8 +785,9 @@ def test_unknown_args():
     p = DebugArghParser()
     p.set_default_command(cmd)
 
+    usage = get_usage_string('[-f FOO]')
+
     assert run(p, '--foo 1') == R(out='1\n', err='')
     assert run(p, '--bar 1', exit=True) == 'unrecognized arguments: --bar 1'
     assert run(p, '--bar 1', exit=False,
-               kwargs={'skip_unknown_args': True}) == \
-           R(out='usage: py.test [-h] [-f FOO]\n\n', err='')
+               kwargs={'skip_unknown_args': True}) == R(out=usage, err='')
